.. atmos documentation master file, created by
   sphinx-quickstart on Tue May 26 14:24:20 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to atmos's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   calculate
   solver
   subclassing
   atmos


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

